Crate comfyui_client
Source Expand description
ComfyUI Client

Rust client for ComfyUI.
Examples
Refer to examples.
License
MulanPSL-2.0
pub use crate::errors::ClientError;pub use crate::errors::ClientResult;
- errors
- Module containing error definitions.
- meta
- Module containing metadata such as prompt and file information.
- ClientBuilder
- A builder for creating a
ComfyUIClient instance. - ComfyUIClient
- A client for interacting with the ComfyUI service.
- EventStream
- A structure representing the event stream received via a websocket
connection.