Struct ExecutedOutput

pub struct ExecutedOutput {
    pub images: Option<Vec<FileInfo>>,
    pub others: HashMap<String, Value>,
}
Represents the output of an executed node.

Contains the results produced by a node in the workflow after successful execution. This can include generated or processed images in the images field, as well as other arbitrary output data in the others map.

Fields

images: Option<Vec<FileInfo>>

Optional list of image file information objects generated or processed by the node.

others: HashMap<String, Value>

Additional output data that doesn’t fit into predefined categories.