Struct EventStream

pub struct EventStream { /* private fields */ }
A structure representing the event stream received via a websocket connection.

This stream continuously processes events from the ComfyUI service.

Methods from Deref<Target = ReceiverStream<ClientResult<Event>>>

pub fn close(&mut self)

Closes the receiving half of a channel without dropping it.

This prevents any further messages from being sent on the channel while still enabling the receiver to drain messages that are buffered. Any outstanding Permit values will still be able to send messages.

To guarantee no messages are dropped, after calling close(), you must receive all items from the stream until None is returned.