Crate comfyui_client

ComfyUI Client

Rust client for ComfyUI.

License

MulanPSL-2.0

Modules

meta
Module containing metadata such as prompt and file information.

Structs

ClientBuilder
A builder for creating a ComfyUIClient instance.
ComfyUIClient
A client for interacting with the ComfyUI service.
EventStream
A structure representing the event stream received via a websocket connection.

Enums

ClientError
Errors that can occur during client operations.

Type Aliases

ClientResult
Type alias for the result of client operations.