Crate comfyui_client
Source Expand description
ComfyUI Client
Rust client for ComfyUI.
License
MulanPSL-2.0
- meta
- Module containing metadata such as prompt and file information.
- ClientBuilder
- A builder for creating a
ComfyUIClient instance. - ComfyUIClient
- A client for interacting with the ComfyUI service.
- EventStream
- A structure representing the event stream received via a websocket
connection.
- ClientError
- Errors that can occur during client operations.
- ClientResult
- Type alias for the result of client operations.